API Reference
=============

Sketch (High-Level)
-------------------

.. autoclass:: planegcs.Sketch
   :members:
   :undoc-members:

SketchSolver (Low-Level)
------------------------

.. autoclass:: planegcs.SketchSolver
   :members:
   :undoc-members:

Enumerations
------------

.. autoclass:: planegcs.SolveStatus
   :members:
   :undoc-members:

.. autoclass:: planegcs.Algorithm
   :members:
   :undoc-members:

.. autoclass:: planegcs.DebugMode
   :members:
   :undoc-members:

.. autoclass:: planegcs.InternalAlignmentType
   :members:
   :undoc-members:
